start

# poen

poen has been removed from Translate Toolkit > 1.2. Rather use podebug as follows:

    podebug --rewrite=en -f "" pot/ po/

Initialises a directory English PO files by taking POT files and copying the msgid to the msgstr.

This is useful for translators who use CAT tools that overwrite/overtype existing text. They can setup their tool to overwrite msgstr entries which will now be in English.

## Prerequisites

GNU Gettext

## Usage

    poen [options] <pot> <en>

Where:

<pot> | a directory of POT files
<en> | a new directory that contains PO files with English translations

Options:

--no-wrap | do not break long message lines, longer than the output page width, into several lines
--po | process .po files instead of the default .pot files

## Bugs

None known